@@ -4,3 +4,5 @@ from light_cnns.AdderNet import *
 from light_cnns.MobileNet import *
 from light_cnns.ShuffleNet import *
 from light_cnns.Attention import *
+from light_cnns.mobile_cpu_network import *
+from light_cnns.ESPNet import *
